from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

RF_GSM = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'BC66', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BC66'}), 'ref_prefix':'U', 'fplist':['RF_GSM:Quectel_BC66'], 'footprint':'RF_GSM:Quectel_BC66', 'keywords':'NB-IoT Data SMS', 'description':'', 'datasheet':'https://www.quectel.com/UploadImage/Downlad/Quectel_BC66_Hardware_Design_V1.1.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GSM.kicad_sym\nBC66\n\nNB-IoT Data SMS', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='SIM_GND',func=pin_types.PWROUT,unit=1),
            Pin(num='11',name='SIM_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SIM_RST',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='SIM_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='SIM_VDD',func=pin_types.PWROUT,unit=1),
            Pin(num='15',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='NETLIGHT',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='PSM_EINT',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='20',name='RI',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='24',name='VDD_EXT',func=pin_types.PWROUT,unit=1),
            Pin(num='25',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='26',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='27',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='RXD_AUX',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='TXD_AUX',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='SPI_MISO',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='31',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='32',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='33',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='RF_ANT',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='RXD_DBG',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='TXD_DBG',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='SPI_MOSI',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='VBAT_BB',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VBAT_RF',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='45',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='46',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='47',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='48',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='49',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='SPI_SCLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='50',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='51',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='52',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='53',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='54',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='55',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='56',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='57',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='58',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='SPI_CS',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='PWRKEY',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='ADC0',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BC95', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BC95'}), 'ref_prefix':'U', 'fplist':['RF_GSM:Quectel_BC95'], 'footprint':'RF_GSM:Quectel_BC95', 'keywords':'NB-IoT GSM GPRS Quad-Band SMS', 'description':'', 'datasheet':'https://www.quectel.com/UploadImage/Downlad/Quectel_BC95_Hardware_Design_V1.3.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GSM.kicad_sym\nBC95\n\nNB-IoT GSM GPRS Quad-Band SMS', 'pins':[
            Pin(num='15',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='NETLIGHT',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='DBG_RXD',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='DBG_TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='ADC',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='VDD_EXT',func=pin_types.PWROUT,unit=1),
            Pin(num='29',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='RI',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='USIM_VDD',func=pin_types.PWROUT,unit=1),
            Pin(num='39',name='USIM_RST',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='USIM_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='USIM_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='USIM_GND',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='VBAT',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='RF_ANT',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='92',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='93',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'M95', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'M95'}), 'ref_prefix':'U', 'fplist':['RF_GSM:Quectel_M95'], 'footprint':'RF_GSM:Quectel_M95', 'keywords':'GSM GPRS AT SMS voice TCP/IP', 'description':'', 'datasheet':'https://www.quectel.com/UploadImage/Downlad/M95_Hardware_Design_V1.3.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GSM.kicad_sym\nM95\n\nGSM GPRS AT SMS voice TCP/IP', 'pins':[
            Pin(num='1',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{PWRKEY}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{EMERG_OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='STATUS',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='NETLIGHT',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DBG_RXD',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='DBG_TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='VDD_EXT',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='MIC2P',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='DTR',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='CTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='RTS',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='DCD',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='RI',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='SIM_VDD',func=pin_types.PWROUT,unit=1),
            Pin(num='28',name='SIM_RST',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='SIM_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='MIC2N',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='SIM_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='SIM_GND',func=pin_types.PWROUT,unit=1),
            Pin(num='32',name='VRTC',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='VBAT',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='RF_ANT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='MIC1P',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='42',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='MIC1N',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SPK1N',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='SPK1P',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='LOUDSPKN',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='LOUDSPKP',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SARA-U201', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SARA-U201'}), 'ref_prefix':'U', 'fplist':['RF_GSM:ublox_SARA_LGA-96'], 'footprint':'RF_GSM:ublox_SARA_LGA-96', 'keywords':'GSM HSPA 2G 3G', 'description':'', 'datasheet':'https://www.u-blox.com/sites/default/files/SARA-U2_DataSheet_(UBX-13005287).pdf', 'search_text':'/usr/share/kicad/symbols/RF_GSM.kicad_sym\nSARA-U201\n\nGSM HSPA 2G 3G', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RTS',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='TXD',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='RXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='PWR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VUSB_DET',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='CODEC_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='V_BCKP',func=pin_types.PWROUT,unit=1),
            Pin(num='20',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='GPIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GPIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GPIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='SCL',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='USB_D-',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='USB_D+',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='34',name='I2S_WA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='I2S_TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='I2S_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='I2S_RXD',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='SIM_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='SIM_IO',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='V_INT',func=pin_types.PWROUT,unit=1),
            Pin(num='40',name='SIM_RST',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='VSIM',func=pin_types.PWROUT,unit=1),
            Pin(num='42',name='SIM_DET',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='45',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='46',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='47',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='48',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='49',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='ANT',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='DSR',func=pin_types.OUTPUT,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='ANT_DET',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='RI',func=pin_types.OUTPUT,unit=1),
            Pin(num='70',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='78',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='DCD',func=pin_types.OUTPUT,unit=1),
            Pin(num='80',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='85',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='87',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='88',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='89',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='DTR',func=pin_types.INPUT,unit=1),
            Pin(num='90',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='92',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='93',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='96',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SIM7020E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SIM7020E'}), 'ref_prefix':'U', 'fplist':['RF_GSM:SIMCom_SIM800C'], 'footprint':'RF_GSM:SIMCom_SIM800C', 'keywords':'NB-IoT Data SMS', 'description':'', 'datasheet':'https://simcom.ee/documents/SIM7020/SIM7020%20Hardware%20Design_V1.02.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GSM.kicad_sym\nSIM7020E\n\nNB-IoT Data SMS', 'pins':[
            Pin(num='1',name='UART1_TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='GPIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RTC_GPIO0',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='RTC_EINT',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='SIM_DET',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SIM_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SIM_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='SIM_RST',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='SIM_VDD',func=pin_types.PWROUT,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='UART1_RXD',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='UART2_TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='UART2_RXD',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='USB_VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='USB_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='USB_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='UART1_RTS',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='ANT',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VBAT',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='ADC',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='~{PWRKEY}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='UART1_CTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='VDD_EXT',func=pin_types.PWROUT,unit=1),
            Pin(num='41',name='NETLIGHT',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='STATUS',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='UART1_DCD',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='UART1_DTR',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='UART1_RI',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDD_3V3',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SIM800C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SIM800C'}), 'ref_prefix':'U', 'fplist':['RF_GSM:SIMCom_SIM800C'], 'footprint':'RF_GSM:SIMCom_SIM800C', 'keywords':'GSM GPRS Quad-Band SMS', 'description':'', 'datasheet':'http://simcom.ee/documents/SIM800C/SIM800C_Hardware_Design_V1.05.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GSM.kicad_sym\nSIM800C\n\nGSM GPRS Quad-Band SMS', 'pins':[
            Pin(num='1',name='UART1_TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='MICN',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SPKP',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='SPKN',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='SIM_DET',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SIM_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SIM_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='SIM_RST',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='SIM_VDD',func=pin_types.PWROUT,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='UART1_RXD',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='BT_ANT',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='UART2_TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='UART2_RXD',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='USB_VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='USB_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='USB_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VRTC',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='RF_SYNC',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='UART1_RTS',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GSM_ANT',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VBAT',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='ADC',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='~{PWRKEY}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='UART1_CTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='VDD_EXT',func=pin_types.PWROUT,unit=1),
            Pin(num='41',name='NETLIGHT',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='STATUS',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='UART1_DCD',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='UART1_DTR',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='UART1_RI',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='MICP',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SIM900', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SIM900'}), 'ref_prefix':'U', 'fplist':['RF_GSM:SIMCom_SIM900'], 'footprint':'RF_GSM:SIMCom_SIM900', 'keywords':'GSM GPRS Quad-Band SMS FAX', 'description':'', 'datasheet':'http://simcom.ee/documents/SIM900/SIM900_Hardware%20Design_V2.05.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GSM.kicad_sym\nSIM900\n\nGSM GPRS Quad-Band SMS FAX', 'pins':[
            Pin(num='1',name='PWRKEY',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='DISP_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='DISP_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='DISP_D/C',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DISP_CS',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='VDD_EXT',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='MIC_P',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='20',name='MIC_N',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='SPK_P',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='SPK_N',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='ADC',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='VRTC',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='DBG_TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='DBG_RXD',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='DTR',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='SIM_VDD',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='SIM_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='SIM_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='SIM_RST',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='SIM_PRESENCE',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PWM1',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='PWM2',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='SCL',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='RI',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='GPIO1/KBR4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='GPIO2/KBR3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='GPIO3/KBR2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='GPIO4/KBR1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GPIO5/KBR0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='GPIO6/KBC4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='GPIO7/KBC3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='GPIO8/KBC2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='DCD',func=pin_types.OUTPUT,unit=1),
            Pin(num='50',name='GPIO9/KBC1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='GPIO10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='NETLIGHT',func=pin_types.OUTPUT,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VBAT',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='VBAT',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='60',name='RF_ANT',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='STATUS',func=pin_types.OUTPUT,unit=1),
            Pin(num='67',name='GPIO11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='GPIO12',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='RTS',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='TXD',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'UL865', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'UL865'}), 'ref_prefix':'U', 'fplist':['RF_GSM:Telit_xL865'], 'footprint':'RF_GSM:Telit_xL865', 'keywords':'gsm 3g gprs umts hspa', 'description':'', 'datasheet':'http://www.telit.com/fileadmin/user_upload/products/Downloads/3G/Telit_UL865_Hardware_User_Guide_r8.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GSM.kicad_sym\nUL865\n\ngsm 3g gprs umts hspa', 'pins':[
            Pin(num='1',name='C109/DCD/GPO',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='SIMRST',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='SIMCLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='SIMIO',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='ADC_IN1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='ADC_IN2',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='DAC_OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VUSB',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='USB_D-',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='USB_D+',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='C125/RING/GPO',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='SPI_CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='GPIO8/STAT_LED',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='GPIO7/SPI_MRDY',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='GPIO6/SPI_SRDY',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='GPIO5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='C107/DSR/GPO',func=pin_types.OUTPUT,unit=1),
            Pin(num='30',name='VRTC',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='32',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='ANTENNA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VBATT_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VBATT',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='GPIO4/DVI_CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='C108/DTR/GPI',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='GPIO3/DVI_TX',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='GPIO2/JDR/DVI_RX',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='GPIO1/DVI_WA0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='V_AUX/PWRMON',func=pin_types.PWROUT,unit=1),
            Pin(num='44',name='RXD_AUX/SPI_MISO',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='TXD_AUX/SPI_MOSI',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='C105/RTS/GPI',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='C106/CTS/GPO',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='C103/TXD',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='C104/RXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='SIMVCC',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SARA-U260', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SARA-U260'}), 'ref_prefix':'U', 'fplist':['RF_GSM:ublox_SARA_LGA-96', 'RF_GSM:ublox_SARA_LGA-96'], 'footprint':'RF_GSM:ublox_SARA_LGA-96', 'keywords':'GSM HSPA 2G 3G', 'description':'', 'datasheet':'https://www.u-blox.com/sites/default/files/SARA-U2_DataSheet_(UBX-13005287).pdf', 'search_text':'/usr/share/kicad/symbols/RF_GSM.kicad_sym\nSARA-U260\n\nGSM HSPA 2G 3G', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RTS',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='TXD',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='RXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='PWR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VUSB_DET',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='CODEC_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='V_BCKP',func=pin_types.PWROUT,unit=1),
            Pin(num='20',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='GPIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GPIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GPIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='SCL',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='USB_D-',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='USB_D+',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='34',name='I2S_WA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='I2S_TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='I2S_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='I2S_RXD',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='SIM_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='SIM_IO',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='V_INT',func=pin_types.PWROUT,unit=1),
            Pin(num='40',name='SIM_RST',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='VSIM',func=pin_types.PWROUT,unit=1),
            Pin(num='42',name='SIM_DET',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='45',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='46',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='47',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='48',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='49',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='ANT',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='DSR',func=pin_types.OUTPUT,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='ANT_DET',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='RI',func=pin_types.OUTPUT,unit=1),
            Pin(num='70',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='78',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='DCD',func=pin_types.OUTPUT,unit=1),
            Pin(num='80',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='85',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='87',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='88',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='89',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='DTR',func=pin_types.INPUT,unit=1),
            Pin(num='90',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='92',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='93',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='96',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SARA-U270', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SARA-U270'}), 'ref_prefix':'U', 'fplist':['RF_GSM:ublox_SARA_LGA-96', 'RF_GSM:ublox_SARA_LGA-96', 'RF_GSM:ublox_SARA_LGA-96'], 'footprint':'RF_GSM:ublox_SARA_LGA-96', 'keywords':'GSM HSPA 2G 3G', 'description':'', 'datasheet':'https://www.u-blox.com/sites/default/files/SARA-U2_DataSheet_(UBX-13005287).pdf', 'search_text':'/usr/share/kicad/symbols/RF_GSM.kicad_sym\nSARA-U270\n\nGSM HSPA 2G 3G', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RTS',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='TXD',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='RXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='PWR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VUSB_DET',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='CODEC_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='V_BCKP',func=pin_types.PWROUT,unit=1),
            Pin(num='20',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='GPIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GPIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GPIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='SCL',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='USB_D-',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='USB_D+',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='34',name='I2S_WA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='I2S_TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='I2S_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='I2S_RXD',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='SIM_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='SIM_IO',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='V_INT',func=pin_types.PWROUT,unit=1),
            Pin(num='40',name='SIM_RST',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='VSIM',func=pin_types.PWROUT,unit=1),
            Pin(num='42',name='SIM_DET',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='45',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='46',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='47',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='48',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='49',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='ANT',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='DSR',func=pin_types.OUTPUT,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='ANT_DET',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='RI',func=pin_types.OUTPUT,unit=1),
            Pin(num='70',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='78',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='DCD',func=pin_types.OUTPUT,unit=1),
            Pin(num='80',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='85',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='87',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='88',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='89',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='DTR',func=pin_types.INPUT,unit=1),
            Pin(num='90',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='92',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='93',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='96',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SARA-U280', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SARA-U280'}), 'ref_prefix':'U', 'fplist':['RF_GSM:ublox_SARA_LGA-96', 'RF_GSM:ublox_SARA_LGA-96', 'RF_GSM:ublox_SARA_LGA-96', 'RF_GSM:ublox_SARA_LGA-96'], 'footprint':'RF_GSM:ublox_SARA_LGA-96', 'keywords':'GSM HSPA 2G 3G', 'description':'', 'datasheet':'https://www.u-blox.com/sites/default/files/SARA-U2_DataSheet_(UBX-13005287).pdf', 'search_text':'/usr/share/kicad/symbols/RF_GSM.kicad_sym\nSARA-U280\n\nGSM HSPA 2G 3G', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RTS',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='TXD',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='RXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='PWR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VUSB_DET',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='CODEC_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='V_BCKP',func=pin_types.PWROUT,unit=1),
            Pin(num='20',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='GPIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GPIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GPIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='SCL',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='USB_D-',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='USB_D+',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='34',name='I2S_WA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='I2S_TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='I2S_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='I2S_RXD',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='SIM_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='SIM_IO',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='V_INT',func=pin_types.PWROUT,unit=1),
            Pin(num='40',name='SIM_RST',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='VSIM',func=pin_types.PWROUT,unit=1),
            Pin(num='42',name='SIM_DET',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='45',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='46',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='47',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='48',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='49',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='ANT',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='DSR',func=pin_types.OUTPUT,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='ANT_DET',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='RI',func=pin_types.OUTPUT,unit=1),
            Pin(num='70',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='78',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='DCD',func=pin_types.OUTPUT,unit=1),
            Pin(num='80',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='85',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='87',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='88',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='89',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='DTR',func=pin_types.INPUT,unit=1),
            Pin(num='90',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='92',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='93',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='96',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SIM7020C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SIM7020C'}), 'ref_prefix':'U', 'fplist':['RF_GSM:SIMCom_SIM800C', 'RF_GSM:SIMCom_SIM800C'], 'footprint':'RF_GSM:SIMCom_SIM800C', 'keywords':'NB-IoT Data SMS', 'description':'', 'datasheet':'https://simcom.ee/documents/SIM7020/SIM7020%20Hardware%20Design_V1.02.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GSM.kicad_sym\nSIM7020C\n\nNB-IoT Data SMS', 'pins':[
            Pin(num='1',name='UART1_TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='GPIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RTC_GPIO0',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='RTC_EINT',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='SIM_DET',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SIM_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SIM_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='SIM_RST',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='SIM_VDD',func=pin_types.PWROUT,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='UART1_RXD',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='UART2_TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='UART2_RXD',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='USB_VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='USB_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='USB_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='UART1_RTS',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='ANT',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VBAT',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='ADC',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='~{PWRKEY}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='UART1_CTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='VDD_EXT',func=pin_types.PWROUT,unit=1),
            Pin(num='41',name='NETLIGHT',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='STATUS',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='UART1_DCD',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='UART1_DTR',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='UART1_RI',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDD_3V3',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] })])


# -*- coding: utf-8 -*-

# The MIT License (MIT) - Copyright (c) Dave Vandenbout.

from .skidl import (
    lib_suffix,
    load_sch_lib,
    parse_lib_part,
    default_lib_paths,
    get_fp_lib_tbl_dir,
)
from . import libs



from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_STC = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'STC15W201S-35x-SOP16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STC15W201S-35x-SOP16'}), 'ref_prefix':'U', 'fplist':['Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'keywords':'STC 8051 microcontroller', 'description':'', 'datasheet':'www.stcmicro.com/datasheet/STC15F2K60S2-en.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_STC.kicad_sym\nSTC15W201S-35x-SOP16\n\nSTC 8051 microcontroller', 'pins':[
            Pin(num='1',name='P1.2/CMPO/T0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='TxD/T2/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='INT0/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='INT1/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{INT2}/RxD_2/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='~{INT3}/TxD_2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P1.0/RSTOUT_LOW',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P1.4/T0CLKO',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CMP-/MCLKO/RST/P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='CMP+/P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RxD/~{INT4}/T2CLKO/P3.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STC8G1K08-38I-TSSOP20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STC8G1K08-38I-TSSOP20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'STC 8051 microcontroller', 'description':'', 'datasheet':'www.stcmicro.com/datasheet/STC8G-en.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_STC.kicad_sym\nSTC8G1K08-38I-TSSOP20\n\nSTC 8051 microcontroller', 'pins':[
            Pin(num='1',name='P1.2/ADC2/SS/T2/ECI',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='INT4/RxD/ADC8/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TxD/ADC9/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='INT0/SCLK_4/SCL_4/ADC10/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='INT1/MISO_4/SDA_4/ADC11/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='CMPO/ECI_2/T1CLKO/MOSI_4/T0/ADC12/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SS_4/CCP0_2/T0CLKO/T1/ADC13/P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='INT2/CMP-/CCP1_2/RxD_2/ADC14/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='INT3/CMP+/CCP2/CCP2_2/TxD_2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P1.0/ADC0/RxD2/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P1.3/ADC3/MOSI/T2CLKO',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P1.1/ADC1/TxD2/CCP0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P1.4/ADC4/MISO/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.5/ADC5/SCLK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.6/ADC6/RxD_3/MCLKO_2/XTALO',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P1.7/ADC7/TxD_3/XTALI',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='MCLKO/RST/P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='P5.5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IAP15W205S-35x-SOP16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IAP15W205S-35x-SOP16'}), 'ref_prefix':'U', 'fplist':['Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'keywords':'STC 8051 microcontroller', 'description':'', 'datasheet':'www.stcmicro.com/datasheet/STC15F2K60S2-en.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_STC.kicad_sym\nIAP15W205S-35x-SOP16\n\nSTC 8051 microcontroller', 'pins':[
            Pin(num='1',name='P1.2/CMPO/T0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='TxD/T2/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='INT0/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='INT1/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{INT2}/RxD_2/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='~{INT3}/TxD_2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P1.0/RSTOUT_LOW',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P1.4/T0CLKO',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CMP-/MCLKO/RST/P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='CMP+/P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RxD/~{INT4}/T2CLKO/P3.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IRC15W207S-35x-SOP16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IRC15W207S-35x-SOP16'}), 'ref_prefix':'U', 'fplist':['Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'keywords':'STC 8051 microcontroller', 'description':'', 'datasheet':'www.stcmicro.com/datasheet/STC15F2K60S2-en.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_STC.kicad_sym\nIRC15W207S-35x-SOP16\n\nSTC 8051 microcontroller', 'pins':[
            Pin(num='1',name='P1.2/CMPO/T0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='TxD/T2/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='INT0/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='INT1/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{INT2}/RxD_2/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='~{INT3}/TxD_2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P1.0/RSTOUT_LOW',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P1.4/T0CLKO',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CMP-/MCLKO/RST/P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='CMP+/P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RxD/~{INT4}/T2CLKO/P3.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STC15W202S-35x-SOP16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STC15W202S-35x-SOP16'}), 'ref_prefix':'U', 'fplist':['Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'keywords':'STC 8051 microcontroller', 'description':'', 'datasheet':'www.stcmicro.com/datasheet/STC15F2K60S2-en.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_STC.kicad_sym\nSTC15W202S-35x-SOP16\n\nSTC 8051 microcontroller', 'pins':[
            Pin(num='1',name='P1.2/CMPO/T0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='TxD/T2/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='INT0/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='INT1/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{INT2}/RxD_2/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='~{INT3}/TxD_2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P1.0/RSTOUT_LOW',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P1.4/T0CLKO',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CMP-/MCLKO/RST/P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='CMP+/P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RxD/~{INT4}/T2CLKO/P3.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STC15W203S-35x-SOP16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STC15W203S-35x-SOP16'}), 'ref_prefix':'U', 'fplist':['Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'keywords':'STC 8051 microcontroller', 'description':'', 'datasheet':'www.stcmicro.com/datasheet/STC15F2K60S2-en.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_STC.kicad_sym\nSTC15W203S-35x-SOP16\n\nSTC 8051 microcontroller', 'pins':[
            Pin(num='1',name='P1.2/CMPO/T0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='TxD/T2/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='INT0/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='INT1/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{INT2}/RxD_2/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='~{INT3}/TxD_2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P1.0/RSTOUT_LOW',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P1.4/T0CLKO',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CMP-/MCLKO/RST/P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='CMP+/P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RxD/~{INT4}/T2CLKO/P3.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STC15W204S-35x-SOP16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STC15W204S-35x-SOP16'}), 'ref_prefix':'U', 'fplist':['Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'keywords':'STC 8051 microcontroller', 'description':'', 'datasheet':'www.stcmicro.com/datasheet/STC15F2K60S2-en.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_STC.kicad_sym\nSTC15W204S-35x-SOP16\n\nSTC 8051 microcontroller', 'pins':[
            Pin(num='1',name='P1.2/CMPO/T0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='TxD/T2/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='INT0/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='INT1/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{INT2}/RxD_2/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='~{INT3}/TxD_2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P1.0/RSTOUT_LOW',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P1.4/T0CLKO',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CMP-/MCLKO/RST/P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='CMP+/P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RxD/~{INT4}/T2CLKO/P3.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STC8G1K04-38I-TSSOP20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STC8G1K04-38I-TSSOP20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'STC 8051 microcontroller', 'description':'', 'datasheet':'www.stcmicro.com/datasheet/STC8G-en.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_STC.kicad_sym\nSTC8G1K04-38I-TSSOP20\n\nSTC 8051 microcontroller', 'pins':[
            Pin(num='1',name='P1.2/ADC2/SS/T2/ECI',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='INT4/RxD/ADC8/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TxD/ADC9/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='INT0/SCLK_4/SCL_4/ADC10/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='INT1/MISO_4/SDA_4/ADC11/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='CMPO/ECI_2/T1CLKO/MOSI_4/T0/ADC12/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SS_4/CCP0_2/T0CLKO/T1/ADC13/P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='INT2/CMP-/CCP1_2/RxD_2/ADC14/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='INT3/CMP+/CCP2/CCP2_2/TxD_2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P1.0/ADC0/RxD2/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P1.3/ADC3/MOSI/T2CLKO',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P1.1/ADC1/TxD2/CCP0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P1.4/ADC4/MISO/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.5/ADC5/SCLK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.6/ADC6/RxD_3/MCLKO_2/XTALO',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P1.7/ADC7/TxD_3/XTALI',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='MCLKO/RST/P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='P5.5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STC8G1K17-38I-TSSOP20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STC8G1K17-38I-TSSOP20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'STC 8051 microcontroller', 'description':'', 'datasheet':'www.stcmicro.com/datasheet/STC8G-en.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_STC.kicad_sym\nSTC8G1K17-38I-TSSOP20\n\nSTC 8051 microcontroller', 'pins':[
            Pin(num='1',name='P1.2/ADC2/SS/T2/ECI',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='INT4/RxD/ADC8/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TxD/ADC9/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='INT0/SCLK_4/SCL_4/ADC10/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='INT1/MISO_4/SDA_4/ADC11/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='CMPO/ECI_2/T1CLKO/MOSI_4/T0/ADC12/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SS_4/CCP0_2/T0CLKO/T1/ADC13/P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='INT2/CMP-/CCP1_2/RxD_2/ADC14/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='INT3/CMP+/CCP2/CCP2_2/TxD_2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P1.0/ADC0/RxD2/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P1.3/ADC3/MOSI/T2CLKO',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P1.1/ADC1/TxD2/CCP0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P1.4/ADC4/MISO/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.5/ADC5/SCLK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.6/ADC6/RxD_3/MCLKO_2/XTALO',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P1.7/ADC7/TxD_3/XTALI',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='MCLKO/RST/P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='P5.5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])


from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_NXP_HC12 = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'MC68HC812A4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC68HC812A4'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'68HC12 Microcontroller', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_HC12.kicad_sym\nMC68HC812A4\n\n68HC12 Microcontroller', 'pins':[
            Pin(num='1',name='VSSX',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PJ7/KWUJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PS3/TXD1',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PS4/SDI/MISO',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PS5/SDO/MOSI',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PS6/SCK',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PS7/SS',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PT0/IOC0',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PT1/IOC1',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PT2/IOC2',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PT3/IOC3',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PT4/IOC4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PG0/A16',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PT5/IOC5',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PT6/IOC6',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PT7/IOC7/PAI',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PG1/A17',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PG2/A18',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PG3/A19',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PG4/A20',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG5/A21',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='BKGD/TAGHI',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDDX',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PD0/D0/KWUD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1/D1/KWUD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2/D2/KWUD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3/D3/KWUD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4/D4/KWUD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5/D5/KWUD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6/D6/KWUD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD7/D7/KWUD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC0/D8/D0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC1/D9/D1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PJ0/KWUJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC2/D10/D2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC3/D11/D3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4/D12/D4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5/D13/D5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC6/D14/D6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC7/D15/D7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE0/XIRQ',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='PE1/IRQ',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='PE2/RW',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3/LSTRB/TAGL0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PJ1/KWUJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RESET',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSSX',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='VDDX',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VDDPLL',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='XFC',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VSSPLL',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='EXTAL',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='XTAL',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='PE4/ECLK',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PE5/MODA/IPIPE0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PJ2/KWUJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PE6/MODB/IPIPE1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PE7/ARST',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PJ3/KWUJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PA0/A8',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PA1/A9',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PA2/A10',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA3/A11',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA4/A12',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PA5/A13',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PA6/A14',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA7/A15',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PF0/CS0',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PF1/CS1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PJ4/KWUJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF2/CS2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF3/CS3',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PF4/CSD',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PF5/CSP0',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PF6/CSP1',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PH0/KWUH0',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PH1/KWUH1',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PH2/KWUH2',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PH3/KWUH3',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VDDX',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PJ5/KWUJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VSSX',func=pin_types.PWRIN,unit=1),
            Pin(num='81',name='PH4/KWUH4',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PH5/KWUH5',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PH6/KWUH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7/KWUH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='VRH',func=pin_types.INPUT,unit=1),
            Pin(num='86',name='VRL',func=pin_types.INPUT,unit=1),
            Pin(num='87',name='PAD0',func=pin_types.INPUT,unit=1),
            Pin(num='88',name='PAD1',func=pin_types.INPUT,unit=1),
            Pin(num='89',name='PAD2',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PJ6/KWUJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PAD3',func=pin_types.INPUT,unit=1),
            Pin(num='91',name='PAD4',func=pin_types.INPUT,unit=1),
            Pin(num='92',name='PAD5',func=pin_types.INPUT,unit=1),
            Pin(num='93',name='PAD6',func=pin_types.INPUT,unit=1),
            Pin(num='94',name='VSTBY/PAD7',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='VDDAD',func=pin_types.INPUT,unit=1),
            Pin(num='96',name='VSSAD',func=pin_types.INPUT,unit=1),
            Pin(num='97',name='PS0/RXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PS1/TXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PS2/RXD1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC68HC912', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC68HC912'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'68HC12 Microcontroller', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_HC12.kicad_sym\nMC68HC912\n\n68HC12 Microcontroller', 'pins':[
            Pin(num='1',name='PP5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PT3-IOC3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PT4-IOC4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PT5-IOC5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PT6-IOC6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PT7-IOC7-PAI',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='BKGD/SMODN/TAGHI',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0/AD0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1/AD1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PP4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2/AD2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB3/AD3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB4/AD4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB5/AD5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB6/AD6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB7/AD7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PE7/DBE',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PE6-MODB/IPIPE1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PE5-MODA/IPIPE0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PE4-ECLK',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PP3/PW3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSX',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VDDX',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='RST',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='EXTAL',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='XTAL',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='PE3/LSTRB/TAGLO',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE2-R/W',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1/IRQ',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='PE0/XIRQ',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='PA0/AD8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PP2/PW3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA1/D9/A9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA2/AD10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA3/AD11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA4/AD12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA5/AD13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6/AD14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA7/AD15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VRH',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PP1/PW1',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VRL',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='PAD0',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='PAD1',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='PAD2',func=pin_types.INPUT,unit=1),
            Pin(num='54',name='PAD3',func=pin_types.INPUT,unit=1),
            Pin(num='55',name='PAD4',func=pin_types.INPUT,unit=1),
            Pin(num='56',name='PAD5',func=pin_types.INPUT,unit=1),
            Pin(num='57',name='PAD6',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PAD7',func=pin_types.INPUT,unit=1),
            Pin(num='59',name='VDDA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='PP0/PW0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='VSSA',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PS0/RxD',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PS1/TxD',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PS2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PS3',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PS4SDI/MISO',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PS5/SD0/MOSI',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PS6/SCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PS7/CS/SS',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='VFP',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='PT0-IOC0',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PDLC6',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PDLC5',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PDLC4',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PDLC3',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PDLC2',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PDLC1/DLCTx',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PDLC0/DLCRx',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='VSSX',func=pin_types.PWRIN,unit=1),
            Pin(num='78',name='VDDX',func=pin_types.PWRIN,unit=1),
            Pin(num='79',name='PP7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PT1-IOC1',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PP6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PT2-IOC2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])